a space or comma delimited string that gives options used when listing keys and signatures (that is, --list-
This is a space or comma delimited string that gives options used when verifying signatures. Options can be prepended
with a `no-' to give the opposite meaning. The options are:
show-photos| Display any photo IDs present on the key that issued the signature. Defaults to no. See also --photo-viewer.
| show-policy-urls|
show policy URLs in the signature being verified. Defaults to yes.
| show-notations|
| show-std-notations|
| show-user-notations|
show all, IETF standard, or user-defined signature notations in the signature being verified. Defaults to IETF
standard.
| show-keyserver-urls|
show any preferred keyserver URL in the signature being verified. Defaults to yes.
| show-uid-validity|
Display the calculated validity of the user IDs on the key that issued the signature. Defaults to yes.
| show-unusable-uids|
show revoked and expired user IDs during signature verification. Defaults to no.
| show-primary-uid-only
| show only the primary user ID during signature verification. That is all the AKA lines as well as photo Ids
are not shown with the signature verification status.
| pka-lookups|
Enable PKA lookups to verify sender addresses. Note that PKA is based on DNS, and so enabling this option may
disclose information on when and what signatures are verified or to whom data is encrypted. This is similar to
the "web bug" described for the --auto-key-retrieve option.
| pka-trust-increase|
Raise the trust in a signature to full if the signature passes PKA validation. This option is only meaningful
if pka-lookups is set.
| --enable-large-rsa |
--disable-large-rsa |
With --generate-key and --batch, enable the creation of RSA secret keys as large as 8192 bit. Note: 8192 bit is more
than is generally recommended. These large keys don't significantly improve security, but they are more expensive to
use, and their signatures and certifications are larger. This option is only available if the binary was build with
large-secmem support.
--enable-dsa2 |
--disable-dsa2 |
Enable hash truncation for all DSA keys even for old DSA Keys up to 1024 bit. This is also the default with
--openpgp. Note that older versions of GnuPG also required this flag to allow the generation of DSA larger than 1024
bit.
--photo-viewer string |
This is the command line that should be run to view a photo ID.
%i will be expanded to a filename containing the photo.
| %I does the same, except the file will not be deleted once the viewer exits. Other flags are
| %k| key ID,
| %K| long key ID, o
| %f| key fingerprint,
| %t| extension of the image type (e.g. "jpg"),
| %T| MIME type of the image (e.g. "image/jpeg"),
| %v| single-character calculated validity of the image being viewed (e.g. "f"),
| %V| calculated validity as a string (e.g. "full"),
| %U| a base32 encoded hash of the user ID, and
| %%| an actual percent sign.
| | | | | | | | | | | |
If neither %i or %I are present, then the photo will be supplied to the viewer on standard input.
default viewer is
xloadimage -fork -quiet -title 'KeyID 0x%k' STDIN"
if your image viewer program is not secure, then executing it from GnuPG does not make it secure.
| --exec-path string |
Sets a list of directories to search for photo viewers and keyserver helpers. If not provided, keyserver helpers use
the compiled-in default directory, and photo viewers use the PATH environment variable. Note, that on W32 system
this value is ignored when searching for keyserver helpers.
--keyring file |
Add file to the current list of keyrings. If file begins with a tilde and a slash, these are replaced by the $HOME
directory. If the filename does not contain a slash, it is assumed to be in the GnuPG home directory ("~/.gnupg" if
--homedir or $GNUPGHOME is not used).
Note that this adds a keyring to the current list. If the intent is to use the specified keyring alone, use --keyring
along with --no-default-keyring.
If the option --no-keyring has been used no keyrings will be used at all.
--secret-keyring file |
This is an obsolete option and ignored. All secret keys are stored in the 'private-keys-v1.d' directory below the
GnuPG home directory.
--primary-keyring file |
Designate file as the primary public keyring. This means that newly imported keys (via --import or keyserver --recv-
from) will go to this keyring.
--trustdb-name file |
Use file instead of the default trustdb. If file begins with a tilde and a slash, these are replaced by the $HOME di-
rectory. If the filename does not contain a slash, it is assumed to be in the GnuPG home directory ('~/.gnupg' if
--homedir or $GNUPGHOME is not used).
--homedir dir |
Set the name of the home directory to dir. If this option is not used, the home directory defaults to '~/.gnupg'. It
is only recognized when given on the command line. It also overrides any home directory stated through the environ-
ment variable 'GNUPGHOME' or (on Windows systems) by means of the Registry entry HKCU\Software\GNU\GnuPG:HomeDir.
On Windows systems it is possible to install GnuPG as a portable application. In this case only this command line
option is considered, all other ways to set a home directory are ignored.
To install GnuPG as a portable application under Windows, create an empty file named 'gpgconf.ctl' in the same direc-
tory as the tool 'gpgconf.exe'. The root of the installation is then that directory; or, if 'gpgconf.exe' has been
installed directly below a directory named 'bin', its parent directory. You also need to make sure that the follow-
ing directories exist and are writable: 'ROOT/home' for the GnuPG home and 'ROOT/var/cache/gnupg' for internal cache
files.
--display-charset name |
Set the name of the native character set. This is used to convert some informational strings like user IDs to the
proper UTF-8 encoding. Note that this has nothing to do with the character set of data to be encrypted or signed;
GnuPG does not recode user-supplied data. If this option is not used, the default character set is determined from
the current locale. A verbosity level of 3 shows the chosen set. Valid values for name are:
iso-8859-1
This is the Latin 1 set.
iso-8859-2
The Latin 2 set.
iso-8859-15
This is currently an alias for the Latin 1 set.
koi8-r The usual Russian set (RFC-1489).
utf-8 Bypass all translations and assume that the OS uses native UTF-8 encoding.
--noutf8-strings |
Assume that command line arguments are given as UTF-8 strings. The default (--no-utf8-strings) is to assume that ar-
guments are encoded in the character set as specified by --display-charset. These options affect all following argu-
ments. Both options may be used multiple times.
| --options file |
Read options from file and do not try to read them from the default options file in the homedir (see --homedir). This
option is ignored if used in an options file.
--no-options |
Shortcut for --options /dev/null. This option is detected before an attempt to open an option file. Using this op-
tion will also prevent the creation of a '~/.gnupg' homedir.
--compress-level n
-z n
--bzip2-compress-level n |
Set compression level to n for the ZIP and ZLIB compression algorithms. The default is to use the default compression
level of zlib (normally 6). --bzip2-compress-level sets the compression level for the BZIP2 compression algorithm
(defaulting to 6 as well). This is a different option from --compress-level since BZIP2 uses a significant amount of
memory for each additional compression level. -z sets both. A value of 0 for n disables compression.
--bzip2-decompress-lowmem |
Use a different decompression method for BZIP2 compressed files. This alternate method uses a bit more than half the
memory, but also runs at half the speed. This is useful under extreme low memory circumstances when the file was
originally compressed at a high --bzip2-compress-level.
--mangle-dos-filenames |
--no-mangle-dos-filenames |
Older version of Windows cannot handle filenames with more than one dot. --mangle-dos-filenames causes GnuPG to re-
place (rather than add to) the extension of an output filename to avoid this problem. This option is off by default
and has no effect on non-Windows platforms.
--ask-cert-level |
--no-ask-cert-level |
When making a key signature, prompt for a certification level. If this option is not specified, the certification
level used is set via --default-cert-level. See --default-cert-level for information on the specific levels and how
they are used. --no-ask-cert-level disables this option. This option defaults to no.
--default-cert-level n |
The default to use for the check level when signing a key.
0 means you make no particular claim as to how carefully you verified the key.
1 means you believe the key is owned by the person who claims to own it but you could not, or did not verify the key
at all. This is useful for a "persona" verification, where you sign the key of a pseudonymous user.
2 means you did casual verification of the key. For example, this could mean that you verified the key fingerprint
and checked the user ID on the key against a photo ID.
3 means you did extensive verification of the key. For example, this could mean that you verified the key fingerprint
with the owner of the key in person, and that you checked, by means of a hard to forge document with a photo ID (such
as a passport) that the name of the key owner matches the name in the user ID on the key, and finally that you veri-
fied (by exchange of email) that the email address on the key belongs to the key owner.
Note that the examples given above for levels 2 and 3 are just that: examples. In the end, it is up to you to decide
just what "casual" and "extensive" mean to you.
This option defaults to 0 (no particular claim).
--min-cert-level |
When building the trust database, treat any signatures with a certification level below this as invalid. Defaults to
2, which disregards level 1 signatures. Note that level 0 "no particular claim" signatures are always accepted.
--trusted-key long key ID |
Assume that the specified key (which must be given as a full 8 byte key ID) is as trustworthy as one of your own se-
cret keys. This option is useful if you don't want to keep your secret keys (or one of them) online but still want to
be able to check the validity of a given recipient's or signator's key.
| | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | |
--trust-model {pgp|classic|tofu|
tofu+pgp| direct|always|auto} |
Set what trust model GnuPG should follow. The models are:
pgp | This is the Web of Trust combined with trust signatures as used in PGP 5.x and later. This is the default
trust model when creating a new trust database.
| classic|
This is the standard Web of Trust as introduced by PGP 2.
| tofu| TOFU stands for Trust On First Use. In this trust model, the first time a key is seen, it is memorized. If
later another key with a user id with the same email address is seen, both keys are marked as suspect. In
that case, the next time either is used, a warning is displayed describing the conflict, why it might have oc-
curred (either the user generated a new key and failed to cross sign the old and new keys, the key is forgery,
or a man-in-the-middle attack is being attempted), and the user is prompted to manually confirm the validity
of the key in question.
Because a potential attacker is able to control the email address and thereby circumvent the conflict detec-
tion algorithm by using an email address that is similar in appearance to a trusted email address, whenever a
message is verified, statistics about the number of messages signed with the key are shown. In this way, a
user can easily identify attacks using fake keys for regular correspondents.
When compared with the Web of Trust, TOFU offers significantly weaker security guarantees. In particular,
TOFU only helps ensure consistency (that is, that the binding between a key and email address doesn't change).
A major advantage of TOFU is that it requires little maintenance to use correctly. To use the web of trust
properly, you need to actively sign keys and mark users as trusted introducers. This is a time-consuming
process and anecdotal evidence suggests that even security-conscious users rarely take the time to do this
thoroughly and instead rely on an ad-hoc TOFU process.
In the TOFU model, policies are associated with bindings between keys and email addresses (which are extracted
from user ids and normalized). There are five policies, which can be set manually using the --tofu-policy op-
tion. The default policy can be set using the --tofu-default-policy option.
The TOFU policies are: auto, good, unknown, bad and ask. The auto policy is used by default (unless overrid-
den by --tofu-default-policy) and marks a binding as marginally trusted. The good, unknown and bad policies
mark a binding as fully trusted, as having unknown trust or as having trust never, respectively. The unknown
policy is useful for just using TOFU to detect conflicts, but to never assign positive trust to a binding.
The final policy, ask prompts the user to indicate the binding's trust. If batch mode is enabled (or input is
inappropriate in the context), then the user is not prompted and the undefined trust level is returned.
| tofu+pgp| This trust model combines TOFU with the Web of Trust. This is done by computing the trust level for each
model and then taking the maximum trust level where the trust levels are ordered as follows: unknown < unde-
fined < marginal < fully < ultimate < expired < never.
By setting --tofu-default-policy=unknown, this model can be used to implement the web of trust with TOFU's
conflict detection algorithm, but without its assignment of positive trust values, which some security-con-
scious users don't like.
| direct Key | validity is set directly by the user and not calculated via the Web of Trust. This model is solely based
on the key and does not distinguish user IDs. Note that when changing to another trust model the trust values
assigned to a key are transformed into ownertrust values, which also indicate how you trust the owner of the
key to sign other keys.
| always | Skip key validation and assume that used keys are always fully valid. You generally won't use this unless you
are using some external validation scheme. This option also suppresses the "[uncertain]" tag printed with sig-
nature checks when there is no evidence that the user ID is bound to the key. Note that this trust model
still does not allow the use of expired, revoked, or disabled keys.
| auto Select the trust model depending on whatever the internal trust database says.
default model if
such a database already exists. Note that a tofu trust model is not considered here and must be enabled explicitly.
| | | | | | | | |
no--auto-key-locate mechanism,… |
locate and retrieve keys as needed when encrypting to an
email address (in the "user@example.com" form), and there are no user@example.com keys on the local keyring.
mechanism are used in order. The option may be given several times to add more mechanisms
The --no-auto-key-locate or the mechanism clear resets the list.
Default local,wkd
cert| use DNS CERT, as specified in RFC-4398.
| pka| use DNS PKA.
| dane| use DANE, as specified in draft-ietf-dane-openpgpkey-05.txt.
| wkd| use the Web Key Directory protocol.
| ldap| use DNS Service Discovery, check the domain in question for any LDAP keyservers to use.
| If this fails, use the PGP Universal method of checking 'ldap://keys.(thedomain)'.
| keyserver| use whatever keyserver is defined using the --keyserver option.
| keyserver-URL| In addition, a keyserver URL as used in the --keyserver option may be used here to query that particular key-server.
| local use the local keyrings. select the order a local key lookup is done. Thus '--auto-key-locate local' is identical to --no-auto-key-locate.
nodefaultdisable the standard local key lookup, done before any of the mechanisms defined by --auto-key-locate
| are tried. The position of this mechanism in the list does not matter. It is not required if local is also used.
| clear| Clear all defined mechanisms. This is useful to override mechanisms given in a config file.
| | | | | | | | | | | |
that a nodefault in mechanisms will also be cleared unless it is given after the clear.
| --no-auto-key-retrieve |
enable or disable the automatic retrieving of keys from a keyserver when verifying signatures made by
keys that are not on the local keyring. The default is --no-auto-key-retrieve.
If the method "wkd" is included in the list of methods given to auto-key-locate, the signer's user ID is part of the
signature, and the option --disable-signer-uid is not used, the "wkd" method may also be used to retrieve a key.
Makes a "web bug" like behavior possible. Keyserver or Web Key Directory operators can see
which keys you request, so by sending you a message signed by a brand new key (which you naturally will not have on
your local keyring), the operator can tell both your IP address and the time when you verified the signature.
| --keyid-format
{none|
short|0xshort|long|0xlong} |
Select how to display key IDs.
none does not show the key ID at all but shows the fingerprint in a separate line.
short traditional 8-character key ID.
long more accurate (but less convenient) 16-character key ID.
Add 0x to either to include an "0x" at the beginning of the key ID, as in 0x99242560.
ignored if the --with-colons is used.
--keyserver name |
deprecated - use the --keyserver in 'dirmngr.conf' instead.
Use name as your keyserver. This is the server that --receive-keys, --send-keys, and --search-keys will communicate
with to receive keys from, send keys to, and search for keys on. The format of the name is a URI: `scheme:[//]key-
servername[:port]' The scheme is the type of keyserver: "hkp" for the HTTP (or compatible) keyservers, "ldap" for the
LDAP keyservers, or "mailto" for the Graff email keyserver. Note that your particular installation of GnuPG may have
other keyserver types available as well. Keyserver schemes are case-insensitive. After the keyserver name, optional
keyserver configuration options may be provided. These are the same as the global --keyserver-options from below, but
apply only to this particular keyserver.
Most keyservers synchronize with each other, so there is generally no need to send keys to more than one server. The
keyserver hkp://keys.gnupg.net uses round robin DNS to give a different keyserver each time you use it.
--keyserver-options {name=value} |
a space or comma delimited string that gives options for the keyserver.
Options prefixed with no- give the opposite meaning.
Valid import-options or export-options may be used here as well to apply to importing
(--recv-key) or exporting (--send-key) a key from a keyserver. While not all options are available for all keyserver
types, some common options are:
include-revoked When searching for a key with --search-keys, include keys that are marked on the keyserver as revoked.
that not all keyservers differentiate between revoked and unrevoked keys, and for such keyservers this option is meaningless.
most keyservers do not have cryptographic verification of key revocations, and
so turning this option off may result in skipping keys that are incorrectly marked as revoked.
| include-disabled | When searching for a key with --search-keys,
include keys that are marked on the keyserver as disabled. Note
that this option is not used with HKP keyservers.
| honor-keyserver-url | When using --refresh-keys, if the key in question has a preferred keyserver URL, then use that preferred keyserver to refresh the key from. In addition,
if auto-key-retrieve is set, and the signature being verified has
a preferred keyserver URL, then use that preferred keyserver to fetch the key from. Note that this option in-
troduces a "web bug": The creator of the key can see when the keys is refreshed.
not enabled by default.
| honor-pka-record | If --auto-key-retrieve is used, and the signature being verified has a PKA record, then use the PKA information to fetch the key. Defaults to "yes".
| include-subkeys | When receiving a key, include subkeys as potential targets. Note that this option is not used with HKP keyservers, as they do not support retrieving keys by subkey id.
| timeout seconds keyserver | helper program how long to try and perform a keyserver action before giving up.
Performing multiple actions at the same time uses this timeout value per action.
For example,
when retrieving multiple keys via --receive-keys, the timeout applies separately to each key retrieval, and
not to the --receive-keys command as a whole. Defaults to 30 seconds.
| | http-proxy=value | deprecated. Set the proxy to use for HTTP and HKP keyservers. overrides proxy defined in dirmngr.conf.
| | |
Use the dirmngr configuration options for:. verbose , debug , check-cert and ca-cert-file
--completes-needed n | Number of completely trusted users to introduce a new key signer (defaults to 1).
--marginals-needed n | Number of marginally trusted users to introduce a new key signer (defaults to 3)
--tofu-default-policy
{auto|good|unknown|bad|ask} |
The default TOFU policy (defaults to auto). For more information about the meaning of this option, see: [trustmodel-tofu].
--max-cert-depth n | Maximum depth of a certification chain (default is 5).
--no-sig-cache |
Do not cache the verification status of key signatures. Caching gives a much better performance in key listings.
However, if you suspect that your public keyring is not safe against write modifications, you can use this option to
disable the caching. It probably does not make sense to disable it because all kind of damage can be done if someone
else has write access to your public keyring.
--no-auto-check-trustdb |
If GnuPG feels that its information about the Web of Trust has to be updated, it automatically runs the --check-
trustdb command internally. This may be a time consuming process. --no-auto-check-trustdb disables this option.
--no-use-agent | This is dummy option. gpg always requires the agent.
--gpg-agent-info |
This is dummy option. It has no effect when used with gpg.
--agent-program file |
Specify an agent program to be used for secret key operations. The default value is determined by running gpgconf
with the option --list-dirs. Note that the pipe symbol (|) is used for a regression test suite hack and may thus not
be used in the file name.
--dirmngr-program file |
Specify a dirmngr program to be used for keyserver access. The default value is '/usr/bin/dirmngr'.
--disable-dirmngr |
Entirely disable the use of the Dirmngr.
--no-autostart |
Do not start the gpg-agent or the dirmngr if it has not yet been started and its service is required. This option is
mostly useful on machines where the connection to gpg-agent has been redirected to another machines. If dirmngr is
required on the remote machine, it may be started manually using gpgconf --launch dirmngr.
--lock-once |
Lock the databases the first time a lock is requested and do not release the lock until the process terminates.
--lock-multiple |
Release the locks every time a lock is no longer needed. Use this to override a previous --lock-once from a config
file.
--lock-never |
Disable locking entirely. This option should be used only in very special environments, where it can be assured that
only one process is accessing those files. A bootable floppy with a stand-alone encryption system will probably use
this. Improper usage of this option may lead to data and key corruption.
--exit-on-status-write-error |
This option will cause write errors on the status FD to immediately terminate the process. That should in fact be the
default but it never worked this way and thus we need an option to enable this, so that the change won't break appli-
cations which close their end of a status fd connected pipe too early. Using this option along with --enable-
progress-filter may be used to cleanly cancel long running gpg operations.
--limit-card-insert-tries n |
With n greater than 0 the number of prompts asking to insert a smartcard gets limited to N-1. Thus with a value of 1
gpg won't at all ask to insert a card if none has been inserted at startup. This option is useful in the configura-
tion file in case an application does not know about the smartcard support and waits ad infinitum for an inserted
card.
--no-random-seed-file |
GnuPG uses a file to store its internal random pool over invocations. This makes random generation faster; however
sometimes write operations are not desired. This option can be used to achieve that with the cost of slower random
generation.
--no-greeting |
Suppress the initial copyright message.
--no-secmem-warning |
Suppress the warning about "using insecure memory".
--no-permission-warning |
Suppress the warning about unsafe file and home directory (--homedir) permissions. Note that the permission checks
that GnuPG performs are not intended to be authoritative, but rather they simply warn about certain common permission
problems. Do not assume that the lack of a warning means that your system is secure.
Note that the warning for unsafe --homedir permissions cannot be suppressed in the gpg.conf file, as this would allow
an attacker to place an unsafe gpg.conf file in place, and use this file to suppress warnings about itself. The
--homedir permissions warning may only be suppressed on the command line.
--require-secmem |
--no-require-secmem |
Refuse to run if GnuPG cannot get secure memory. Defaults to no (i.e. run, but give a warning).
--require-cross-certification |
--no-require-cross-certification |
When verifying a signature made from a subkey, ensure that the cross certification "back signature" on the subkey is
present and valid. This protects against a subtle attack against subkeys that can sign. Defaults to --require-
cross-certification for gpg.
--expert |
--no-expert |
Allow the user to do certain nonsensical or "silly" things like signing an expired or revoked key, or certain poten-
tially incompatible things like generating unusual key types. This also disables certain warning messages about po-
tentially incompatible actions. As the name implies, this option is for experts only. If you don't fully understand
the implications of what it allows you to do, leave this off. --no-expert disables this option.
| | | | | | | | | | | | | | | | | | | | | | | | | | | | | |
Key related options
--recipient name |
-r Encrypt for user id name. If this option or --hidden-recipient is not specified, GnuPG asks for the user-id unless
--default-recipient is given.
--hidden-recipient name |
-R Encrypt for user ID name, but hide the key ID of this user's key. This option helps to hide the receiver of the mes-
sage and is a limited countermeasure against traffic analysis. If this option or --recipient is not specified, GnuPG
asks for the user ID unless --default-recipient is given.
--recipient-file file |
-f This option is similar to --recipient except that it encrypts to a key stored in the given file. file must be the
name of a file containing exactly one key. gpg assumes that the key in this file is fully valid.
--hidden-recipient-file file |
-F This option is similar to --hidden-recipient except that it encrypts to a key stored in the given file. file must be
the name of a file containing exactly one key. gpg assumes that the key in this file is fully valid.
--encrypt-to name |
Same as --recipient but this one is intended for use in the options file and may be used with your own user-id as an
"encrypt-to-self". These keys are only used when there are other recipients given either by use of --recipient or by
the asked user id. No trust checking is performed for these user ids and even disabled keys can be used.
--hidden-encrypt-to name |
Same as --hidden-recipient but this one is intended for use in the options file and may be used with your own user-id
as a hidden "encrypt-to-self". These keys are only used when there are other recipients given either by use of --re-
cipient or by the asked user id. No trust checking is performed for these user ids and even disabled keys can be
used.
--no-encrypt-to |
Disable the use of all --encrypt-to and --hidden-encrypt-to keys.
--group {name=value} |
Sets up a named group, which is similar to aliases in email programs. Any time the group name is a recipient (-r or
--recipient), it will be expanded to the values specified. Multiple groups with the same name are automatically
merged into a single group.
The values are key IDs or fingerprints, but any key description is accepted. Note that a value with spaces in it will
be treated as two different values. Note also there is only one level of expansion --- you cannot make an group that
points to another group. When used from the command line, it may be necessary to quote the argument to this option to
prevent the shell from treating it as multiple arguments.
--ungroup name |
Remove a given entry from the --group list.
--no-groups |
Remove all entries from the --group list.
--local-user name |
-u Use name as the key to sign with. Note that this option overrides --default-key.
--sender mbox |
This option has two purposes. mbox must either be a complete user id with a proper mail address or just a mail ad-
dress. When creating a signature this option tells gpg the user id of a key used to make a signature if the key was
not directly specified by a user id. When verifying a signature the mbox is used to restrict the information printed
by the TOFU code to matching user ids.
--try-secret-key name |
For hidden recipients GPG needs to know the keys to use for trial decryption. The key set with --default-key is al-
ways tried first, but this is often not sufficient. This option allows setting more keys to be used for trial de-
cryption. Although any valid user-id specification may be used for name it makes sense to use at least the long
keyid to avoid ambiguities. Note that gpg-agent might pop up a pinentry for a lot keys to do the trial decryption.
If you want to stop all further trial decryption you may use close-window button instead of the cancel button.
--try-all-secrets |
Don't look at the key ID as stored in the message but try all secret keys in turn to find the right decryption key.
This option forces the behaviour as used by anonymous recipients (created by using --throw-keyids or --hidden-recipi-
ent) and might come handy in case where an encrypted message contains a bogus key ID.
--skip-hidden-recipients |
--no-skip-hidden-recipients |
During decryption skip all anonymous recipients. This option helps in the case that people use the hidden recipients
feature to hide their own encrypt-to key from others. If one has many secret keys this may lead to a major annoyance
because all keys are tried in turn to decrypt something which was not really intended for it. The drawback of this
option is that it is currently not possible to decrypt a message which includes real anonymous recipients.
| | | | | | | | | | | | | | | |
Input and Output
--armor |
-a Create ASCII armored output. The default is to create the binary OpenPGP format.
--no-armor |
Assume the input data is not in ASCII armored format.
--output file |
-o file
Write output to file. To write to stdout use - as the filename.
--max-output n |
This option sets a limit on the number of bytes that will be generated when processing a file. Since OpenPGP supports
various levels of compression, it is possible that the plaintext of a given message may be significantly larger than
the original OpenPGP message. While GnuPG works properly with such messages, there is often a desire to set a maximum
file size that will be generated before processing is forced to stop by the OS limits. Defaults to 0, which means "no
limit".
--input-size-hint n |
This option can be used to tell GPG the size of the input data in bytes. n must be a positive base-10 number. This
option is only useful if the input is not taken from a file. GPG may use this hint to optimize its buffer allocation
strategy. It is also used by the --status-fd line ``PROGRESS'' to provide a value for ``total'' if that is not
available by other means.
--key-origin string[,url] |
gpg can track the origin of a key. Certain origins are implicitly known (e.g. keyserver, web key directory) and set.
For a standard import the origin of the keys imported can be set with this option. To list the possible values use
"help" for string. Some origins can store an optional url argument. That URL can appended to string after a comma.
--import-options parameters |
This is a space or comma delimited string that gives options for importing keys. Options can be prepended with a
`no-' to give the opposite meaning. The options are:
import-local-sigs
Allow importing key signatures marked as "local". This is not generally useful unless a shared keyring scheme
is being used. Defaults to no.
keep-ownertrust
Normally possible still existing ownertrust values of a key are cleared if a key is imported. This is in gen-
eral desirable so that a formerly deleted key does not automatically gain an ownertrust values merely due to
import. On the other hand it is sometimes necessary to re-import a trusted set of keys again but keeping al-
ready assigned ownertrust values. This can be achieved by using this option.
repair-pks-subkey-bug
During import, attempt to repair the damage caused by the PKS keyserver bug (pre version 0.9.6) that mangles
keys with multiple subkeys. Note that this cannot completely repair the damaged key as some crucial data is
removed by the keyserver, but it does at least give you back one subkey. Defaults to no for regular --import
and to yes for keyserver --receive-keys.
import-show
show-only
Show a listing of the key as imported right before it is stored. This can be combined with the option --dry-
run to only look at keys; the option show-only is a shortcut for this combination. The command --show-keys is
another shortcut for this. Note that suffixes like '#' for "sec" and "sbb" lines may or may not be printed.
import-export
Run the entire import code but instead of storing the key to the local keyring write it to the output. The
export options export-pka and export-dane affect the output. This option can be used to remove all invalid
parts from a key without the need to store it.
merge-only
During import, allow key updates to existing keys, but do not allow any new keys to be imported. Defaults to
no.
import-clean
After import, compact (remove all signatures except the self-signature) any user IDs from the new key that are
not usable. Then, remove any signatures from the new key that are not usable. This includes signatures that
were issued by keys that are not present on the keyring. This option is the same as running the --edit-key
command "clean" after import. Defaults to no.
repair-keys. After import, fix various problems with the
keys. For example, this reorders signatures, and strips duplicate signatures. Defaults to yes.
import-minimal
Import the smallest key possible. This removes all signatures except the most recent self-signature on each
user ID. This option is the same as running the --edit-key command "minimize" after import. Defaults to no.
restore
import-restore
Import in key restore mode. This imports all data which is usually skipped during import; including all GnuPG
specific data. All other contradicting options are overridden.
--import-filter {name=expr} |
--export-filter {name=expr} |
These options define an import/export filter which are applied to the imported/exported keyblock right before it will
be stored/written. name defines the type of filter to use, expr the expression to evaluate. The option can be used
several times which then appends more expression to the same name.
The available filter types are:
keep-uid
This filter will keep a user id packet and its dependent packets in the keyblock if the expression evaluates
to true.
drop-subkey
This filter drops the selected subkeys. Currently only implemented for --export-filter.
drop-sig
This filter drops the selected key signatures on user ids. Self-signatures are not considered. Currently
only implemented for --import-filter.
For the syntax of the expression see the chapter "FILTER EXPRESSIONS". The property names for the expressions depend on the
actual filter type and are indicated in the following table.
The available properties are:
uid A string with the user id. (keep-uid)
mbox The addr-spec part of a user id with mailbox or the empty string. (keep-uid)
key_algo
A number with the public key algorithm of a key or subkey packet. (drop-subkey)
key_created
key_created_d
The first is the timestamp a public key or subkey packet was created. The second is the same but given as an
ISO string, e.g. "2016-08-17". (drop-subkey)
primary
Boolean indicating whether the user id is the primary one. (keep-uid)
expired
Boolean indicating whether a user id (keep-uid), a key (drop-subkey), or a signature (drop-sig) expired.
revoked
Boolean indicating whether a user id (keep-uid) or a key (drop-subkey) has been revoked.
disabled
Boolean indicating whether a primary key is disabled. (not used)
secret Boolean indicating whether a key or subkey is a secret one. (drop-subkey)
usage A string indicating the usage flags for the subkey, from the sequence ``ecsa?''. For example, a subkey capa-
ble of just signing and authentication would be an exact match for ``sa''. (drop-subkey)
sig_created
sig_created_d
The first is the timestamp a signature packet was created. The second is the same but given as an ISO date
string, e.g. "2016-08-17". (drop-sig)
sig_algo
A number with the public key algorithm of a signature packet. (drop-sig)
sig_digest_algo
A number with the digest algorithm of a signature packet. (drop-sig)
--export-options parameters |
a space or comma delimited string that gives options for exporting keys. Options can be prepended with a
`no-' to give the opposite meaning. The options are:
export-local-sigs Allow exporting key signatures marked as "local". This is not generally useful unless a shared keyring scheme is being used. Defaults to no.
export-attributes Include attribute user IDs (photo IDs) while exporting. Not including attribute user IDs is useful to export
keys that are going to be used by an OpenPGP program that does not accept attribute user IDs. Defaults to yes.
export-sensitive-revkeys Include designated revoker information that was marked as "sensitive". Defaults to no.
backup
export-backup Export for use as a backup. The exported data includes all data which is needed to restore the key or keys
later with GnuPG. The format is basically the OpenPGP format but enhanced with GnuPG specific data. All
other contradicting options are overridden.
export-clean Compact (remove all signatures from) user IDs on the key being exported if the user IDs are not usable. Also,
do not export any signatures that are not usable. This includes signatures that were issued by keys that are
not present on the keyring. This option is the same as running the --edit-key command "clean" before export
except that the local copy of the key is not modified. Defaults to no.
export-minimal Export the smallest key possible. This removes all signatures except the most recent self-signature on each
user ID. This option is the same as running the --edit-key command "minimize" before export except that the
local copy of the key is not modified. Defaults to no.
export-pka Instead of outputting the key material output PKA records suitable to put into DNS zone files. An ORIGIN line
is printed before each record to allow diverting the records to the corresponding zone file.
export-dane Instead of outputting the key material output OpenPGP DANE records suitable to put into DNS zone files. An
ORIGIN line is printed before each record to allow diverting the records to the corresponding zone file.
--with-colons |
Print key listings delimited by colons. Note that the output will be encoded in UTF-8 regardless of any --display-
charset setting. This format is useful when GnuPG is called from scripts and other programs as it is easily machine
parsed. The details of this format are documented in the file 'doc/DETAILS', which is included in the GnuPG source
distribution.
--fixed-list-mode |
Do not merge primary user ID and primary key in --with-colon listing mode and print all timestamps as seconds since 1970-01-01.
--legacy-list-mode |
Revert to the pre-2.1 public key list mode. This only affects the human readable output and not the machine interface (i.e. --with-colons). legacy format does not convey suitable information for elliptic curves.
--with-fingerprint |
as qwith --fingerprint but changes only the format of the output and may be used together with another command.
--with-subkey-fingerprint |
If a fingerprint is printed for the primary key, this option forces printing of the fingerprint for all subkeys.
This could also be achieved by using the --with-fingerprint twice but by using this option along with keyid-format
"none" a compact fingerprint is printed.
--with-icao-spelling | Display the ICAO spelling of the fingerprint in addition to the hex digits.
--with-keygrip |
Include the keygrip in the key listings. In --with-colons mode this is implicitly enable for secret keys.
--with-key-origin |
Include the locally held information on the origin and last update of a key in a key listing. In --with-colons mode
this is always printed. This data is currently experimental and shall not be considered part of the stable API.
--with-wkd-hash |
Print a Web Key Directory identifier along with each user ID in key listings. This is an experimental feature and
semantics may change.
--with-secret | Include info about the presence of a secret key in public key listings done with --with-colons.
| | | | | | | | | | | | | | | | | | | |
OpenPGP protocol specific options
-t, --textmode |
--no-textmode |
Treat input files as text and store them in the OpenPGP canonical text form with standard "CRLF" line endings. This
also sets the necessary flags to inform the recipient that the encrypted or signed data is text and may need its line
endings converted back to whatever the local system uses. This option is useful when communicating between two plat-
forms that have different line ending conventions (UNIX-like to Mac, Mac to Windows, etc). --no-textmode disables
this option, and is the default.
--force-v3-sigs |
--no-force-v3-sigs |
--force-v4-certs
--no-force-v4-certs |
These options are obsolete and have no effect since GnuPG 2.1.
--force-mdc
--disable-mdc |
These options are obsolete and have no effect since GnuPG 2.2.8. The MDC is always used. But note: If the creation
of a legacy non-MDC message is exceptionally required, the option --rfc2440 allows for this.
--disable-signer-uid |
By default the user ID of the signing key is embedded in the data signature. As of now this is only done if the
signing key has been specified with local-user using a mail address. This information can be helpful for verifier to
locate the key; see option --auto-key-retrieve.
--personal-cipher-preferences string |
Set the list of personal cipher preferences to string. Use gpg --version to get a list of available algorithms, and
use none to set no preference at all. This allows the user to safely override the algorithm chosen by the recipient
key preferences, as GPG will only select an algorithm that is usable by all recipients. The most highly ranked ci-
pher in this list is also used for the --symmetric encryption command.
--personal-digest-preferences string |
Set the list of personal digest preferences to string. Use gpg --version to get a list of available algorithms, and
use none to set no preference at all. This allows the user to safely override the algorithm chosen by the recipient
key preferences, as GPG will only select an algorithm that is usable by all recipients. The most highly ranked di-
gest algorithm in this list is also used when signing without encryption (e.g. --clear-sign or --sign).
--personal-compress-preferences string |
Set the list of personal compression preferences to string. Use gpg --version to get a list of available algorithms,
and use none to set no preference at all. This allows the user to safely override the algorithm chosen by the recip-
ient key preferences, as GPG will only select an algorithm that is usable by all recipients. The most highly ranked
compression algorithm in this list is also used when there are no recipient keys to consider (e.g. --symmetric).
--s2k-cipher-algo name |
Use name as the cipher algorithm for symmetric encryption with a passphrase if --personal-cipher-preferences and
--cipher-algo are not given. The default is AES-128.
--s2k-digest-algo name |
Use name as the digest algorithm used to mangle the passphrases for symmetric encryption. The default is SHA-1.
--s2k-mode n |
Selects how passphrases for symmetric encryption are mangled. If n is 0 a plain passphrase (which is in general not
recommended) will be used, a 1 adds a salt (which should not be used) to the passphrase and a 3 (the default) iter-
ates the whole process a number of times (see --s2k-count).
--s2k-count n |
Specify how many times the passphrases mangling for symmetric encryption is repeated. This value may range between
1024 and 65011712 inclusive. The default is inquired from gpg-agent. Note that not all values in the 1024-65011712
range are legal and if an illegal value is selected, GnuPG will round up to the nearest legal value. This option is
only meaningful if --s2k-mode is set to the default of 3.
| | | | | | | | | | | | |
Compliance options
These options control what GnuPG is compliant to. Only one of these options may be active at a time. Note that the default
setting of this is nearly always the correct one. See the INTEROPERABILITY WITH OTHER OPENPGP PROGRAMS section below before
using one of these options.
| --gnupg |
Use standard GnuPG behavior. This is essentially OpenPGP behavior (see --openpgp), but with some additional workarounds for common compatibility problems in different versions of PGP. This is the default option, so it is not generally needed, but it may be useful to override a different compliance option in the gpg.conf file.
--openpgp |
Reset all packet, cipher and digest options to strict OpenPGP behavior. Use this option to reset all previous options
like --s2k-*, --cipher-algo, --digest-algo and --compress-algo to OpenPGP compliant values. All PGP workarounds are
disabled.
--rfc4880 |
Reset all packet, cipher and digest options to strict RFC-4880 behavior. same as --openpgp.
--rfc4880bis |
Enable experimental features from proposed updates to RFC-4880. This option can be used in addition to the other
compliance options. Warning: The behavior may change with any GnuPG release and created keys or data may not be usable with future GnuPG versions.
--rfc2440 |
Reset all packet, cipher and digest options to strict RFC-2440 behavior.
option encryption
packets are created in a legacy mode without MDC protection. This is dangerous and should thus only be used for experiments. See also option --ignore-mdc-error.
--pgp6 | PGP 6 compliant as possible. This restricts you to the ciphers IDEA (if the IDEA plugin
is installed), 3DES, and CAST5, the hashes MD5, SHA1 and RIPEMD160, and the compression algorithms none and ZIP. This
also disables --throw-keyids, and making signatures with signing subkeys as PGP 6 does not understand signatures made
by signing subkeys.
implies --escape-from-lines.
--pgp7 | PGP 7 compliant as possible. simialr to --pgp6 except that MDCs are not disabled, and the list of allowable ciphers is expanded to add AES128, AES192, AES256, and TWOFISH.
--pgp8 | PGP 8 compliant as possible. PGP 8 is a lot closer to the OpenPGP standard than previous
versions of PGP, so all this does is disable --throw-keyids and set --escape-from-lines. All algorithms are allowed
except for the SHA224, SHA384, and SHA512 digests.
--compliance string |
used instead of one of the options above. Valid values for string are the above option names
(without the double dash) and possibly others as shown when using "help" for value.
| | | | | | | | |
Doing things one usually doesn't want to do
-n
| --dry-run |
Don't make any changes (this is not completely implemented).
--list-only |
Changes the behaviour of some commands. This is like --dry-run but different in some cases. The semantic of this op-
tion may be extended in the future. Currently it only skips the actual decryption pass and therefore enables a fast
listing of the encryption keys.
-i
--interactive |
Prompt before overwriting any files.
--debug-level level |
Select the debug level for investigating problems. level may be a numeric value or by a keyword:
none No debugging at all. A value of less than 1 may be used instead of the keyword.
basic Some basic debug messages. A value between 1 and 2 may be used instead of the keyword.
advanced
More verbose debug messages. A value between 3 and 5 may be used instead of the keyword.
expert Even more detailed messages. A value between 6 and 8 may be used instead of the keyword.
guru All of the debug messages you can get. A value greater than 8 may be used instead of the keyword. The cre-
ation of hash tracing files is only enabled if the keyword is used.
How these messages are mapped to the actual debugging flags is not specified and may change with newer releases of this pro-
gram. They are however carefully selected to best aid in debugging.
--debug flags |
Set debugging flags. All flags are or-ed and flags may be given in C syntax (e.g. 0x0042) or as a comma separated
list of flag names. To get a list of all supported flags the single word "help" can be used.
--debug-all |
Set all useful debugging flags.
--debug-iolbf |
Set stdout into line buffered mode. This option is only honored when given on the command line.
--faked-system-time epoch |
This option is only useful for testing; it sets the system time back or forth to epoch which is the number of seconds
elapsed since the year 1970. Alternatively epoch may be given as a full ISO time string (e.g. "20070924T154812").
If you suffix epoch with an exclamation mark (!), the system time will appear to be frozen at the specified time.
--enable-progress-filter |
Enable certain PROGRESS status outputs. This option allows frontends to display a progress indicator while gpg is
processing larger files. There is a slight performance overhead using it.
--status-fd n |
Write special status strings to the file descriptor n. See the file DETAILS in the documentation for a listing of
them.
--status-file file |
Same as --status-fd, except the status data is written to file file.
--logger-fd n |
Write log output to file descriptor n and not to STDERR.
--log-file file |
--logger-file file |
Same as --logger-fd, except the logger data is written to file file. Use 'socket://' to log to s socket.
--attribute-fd n |
Write attribute subpackets to the file descriptor n. This is most useful for use with --status-fd, since the status
messages are needed to separate out the various subpackets from the stream delivered to the file descriptor.
--attribute-file file |
Same as --attribute-fd, except the attribute data is written to file file.
--comment string |
--no-comments |
Use string as a comment string in cleartext signatures and ASCII armored messages or keys (see --armor). The default
behavior is not to use a comment string. --comment may be repeated multiple times to get multiple comment strings.
--no-comments removes all comments. It is a good idea to keep the length of a single comment below 60 characters to
avoid problems with mail programs wrapping such lines. Note that comment lines, like all other header lines, are not
protected by the signature.
--emit-version |
--no-emit-version |
Force inclusion of the version string in ASCII armored output. If given once only the name of the program and the
major number is emitted, given twice the minor is also emitted, given thrice the micro is added, and given four times
an operating system identification is also emitted. --no-emit-version (default) disables the version line.
--sig-notation {name=value} |
--cert-notation {name=value} |
-N, --set-notation {name=value}
Put the name value pair into the signature as notation data. name must consist only of printable characters or spa-
ces, and must contain a '@' character in the form keyname@domain.example.com (substituting the appropriate keyname
and domain name, of course). This is to help prevent pollution of the IETF reserved notation namespace. The --expert
flag overrides the '@' check. value may be any printable string; it will be encoded in UTF-8, so you should check
that your --display-charset is set correctly. If you prefix name with an exclamation mark (!), the notation data will
be flagged as critical (rfc4880:5.2.3.16). --sig-notation sets a notation for data signatures. --cert-notation sets a
notation for key signatures (certifications). --set-notation sets both.
There are special codes that may be used in notation names. "%k" will be expanded into the key ID of the key being
signed, "%K" into the long key ID of the key being signed, "%f" into the fingerprint of the key being signed, "%s"
into the key ID of the key making the signature, "%S" into the long key ID of the key making the signature, "%g" into
the fingerprint of the key making the signature (which might be a subkey), "%p" into the fingerprint of the primary
key of the key making the signature, "%c" into the signature count from the OpenPGP smartcard, and "%%" results in a
single "%". %k, %K, and %f are only meaningful when making a key signature (certification), and %c is only meaningful
when using the OpenPGP smartcard.
--known-notation name |
Adds name to a list of known critical signature notations. The effect of this is that gpg will not mark a signature
with a critical signature notation of that name as bad. Note that gpg already knows by default about a few critical
signatures notation names.
--sig-policy-url string |
--cert-policy-url string |
--set-policy-url string |
Use string as a Policy URL for signatures (rfc4880:5.2.3.20). If you prefix it with an exclamation mark (!), the
policy URL packet will be flagged as critical. --sig-policy-url sets a policy url for data signatures. --cert-policy-
url sets a policy url for key signatures (certifications). --set-policy-url sets both.
The same %-expandos used for notation data are available here as well.
--sig-keyserver-url string |
Use string as a preferred keyserver URL for data signatures. If you prefix it with an exclamation mark (!), the key-
server URL packet will be flagged as critical.
The same %-expandos used for notation data are available here as well.
--set-filename string |
Use string as the filename which is stored inside messages. This overrides the default, which is to use the actual
filename of the file being encrypted. Using the empty string for string effectively removes the filename from the
output.
--for-your-eyes-only |
--no-for-your-eyes-only |
Set the `for your eyes only' flag in the message. This causes GnuPG to refuse to save the file unless the --output
option is given, and PGP to use a "secure viewer" with a claimed Tempest-resistant font to display the message. This
option overrides --set-filename. --no-for-your-eyes-only disables this option.
--use-embedded-filename |
--no-use-embedded-filename |
Try to create a file with a name as embedded in the data. This can be a dangerous option as it enables overwriting
files. Defaults to no.
--cipher-algo name |
Use name as cipher algorithm. Running the program with the command --version yields a list of supported algorithms.
If this is not used the cipher algorithm is selected from the preferences stored with the key. In general, you do not
want to use this option as it allows you to violate the OpenPGP standard. --personal-cipher-preferences is the safe
way to accomplish the same thing.
--digest-algo name |
Use name as the message digest algorithm. Running the program with the command --version yields a list of supported
algorithms. In general, you do not want to use this option as it allows you to violate the OpenPGP standard. --per-
sonal-digest-preferences is the safe way to accomplish the same thing.
--compress-algo name |
Use compression algorithm name. "zlib" is RFC-1950 ZLIB compression. "zip" is RFC-1951 ZIP compression which is used
by PGP. "bzip2" is a more modern compression scheme that can compress some things better than zip or zlib, but at
the cost of more memory used during compression and decompression. "uncompressed" or "none" disables compression. If
this option is not used, the default behavior is to examine the recipient key preferences to see which algorithms the
recipient supports. If all else fails, ZIP is used for maximum compatibility.
ZLIB may give better compression results than ZIP, as the compression window size is not limited to 8k. BZIP2 may
give even better compression results than that, but will use a significantly larger amount of memory while compress-
ing and decompressing. This may be significant in low memory situations. Note, however, that PGP (all versions) only
supports ZIP compression. Using any algorithm other than ZIP or "none" will make the message unreadable with PGP. In
general, you do not want to use this option as it allows you to violate the OpenPGP standard. --personal-compress-
preferences is the safe way to accomplish the same thing.
--cert-digest-algo name |
Use name as the message digest algorithm used when signing a key. Running the program with the command --version
yields a list of supported algorithms. Be aware that if you choose an algorithm that GnuPG supports but other OpenPGP
implementations do not, then some users will not be able to use the key signatures you make, or quite possibly your
entire key.
--disable-cipher-algo name |
Never allow the use of name as cipher algorithm. The given name will not be checked so that a later loaded algorithm
will still get disabled.
--disable-pubkey-algo name |
Never allow the use of name as public key algorithm. The given name will not be checked so that a later loaded algo-
rithm will still get disabled.
--throw-keyids |
--no-throw-keyids |
Do not put the recipient key IDs into encrypted messages. This helps to hide the receivers of the message and is a
limited countermeasure against traffic analysis. ([Using a little social engineering anyone who is able to decrypt
the message can check whether one of the other recipients is the one he suspects.]) On the receiving side, it may
slow down the decryption process because all available secret keys must be tried. --no-throw-keyids disables this
option. This option is essentially the same as using --hidden-recipient for all recipients.
--not-dash-escaped |
This option changes the behavior of cleartext signatures so that they can be used for patch files. You should not
send such an armored file via email because all spaces and line endings are hashed too. You can not use this option
for data which has 5 dashes at the beginning of a line, patch files don't have this. A special armor header line
tells GnuPG about this cleartext signature option.
--escape-from-lines |
--no-escape-from-lines |
Because some mailers change lines starting with "From " to ">From " it is good to handle such lines in a special way
when creating cleartext signatures to prevent the mail system from breaking the signature. Note that all other PGP
versions do it this way too. Enabled by default. --no-escape-from-lines disables this option.
--passphrase-repeat n |
Specify how many times gpg will request a new passphrase be repeated. This is useful for helping memorize a
passphrase. Defaults to 1 repetition.
--passphrase-fd n |
Read the passphrase from file descriptor n. Only the first line will be read from file descriptor n. If you use 0 for
n, the passphrase will be read from STDIN. This can only be used if only one passphrase is supplied.
Note that since Version 2.0 this passphrase is only used if the option --batch has also been given. Since Version 2.1
the --pinentry-mode also needs to be set to loopback.
--passphrase-file file |
Read the passphrase from file file. Only the first line will be read from file file. This can only be used if only
one passphrase is supplied. Obviously, a passphrase stored in a file is of questionable security if other users can
read this file. Don't use this option if you can avoid it.
Note that since Version 2.0 this passphrase is only used if the option --batch has also been given. Since Version 2.1
the --pinentry-mode also needs to be set to loopback.
--passphrase string |
Use string as the passphrase. This can only be used if only one passphrase is supplied. Obviously, this is of very
questionable security on a multi-user system. Don't use this option if you can avoid it.
Note that since Version 2.0 this passphrase is only used if the option --batch has also been given. Since Version 2.1
the --pinentry-mode also needs to be set to loopback.
--pinentry-mode mode |
Set the pinentry mode to mode. Allowed values for mode are:
default
Use the default of the agent, which is ask.
ask Force the use of the Pinentry.
cancel Emulate use of Pinentry's cancel button.
error Return a Pinentry error (``No Pinentry'').
loopback
Redirect Pinentry queries to the caller. Note that in contrast to Pinentry the user is not prompted again if
he enters a bad password.
--no-symkey-cache |
Disable the passphrase cache used for symmetrical en- and decryption. This cache is based on the message specific
salt value (cf. --s2k-mode).
--request-origin origin |
Tell gpg to assume that the operation ultimately originated at origin. Depending on the origin certain restrictions
are applied and the Pinentry may include an extra note on the origin. Supported values for origin are: local which
is the default, remote to indicate a remote origin or browser for an operation requested by a web browser.
--command-fd n |
This is a replacement for the deprecated shared-memory IPC mode. If this option is enabled, user input on questions
is not expected from the TTY but from the given file descriptor. It should be used together with --status-fd. See the
file doc/DETAILS in the source distribution for details on how to use it.
--command-file file |
Same as --command-fd, except the commands are read out of file file
--allow-non-selfsigned-uid |
--no-allow-non-selfsigned-uid |
Allow the import and use of keys with user IDs which are not self-signed. This is not recommended, as a non self-
signed user ID is trivial to forge. --no-allow-non-selfsigned-uid disables.
--allow-freeform-uid |
Disable all checks on the form of the user ID while generating a new one. This option should only be used in very
special environments as it does not ensure the de-facto standard format of user IDs.
--ignore-time-conflict |
GnuPG normally checks that the timestamps associated with keys and signatures have plausible values. However, some-
times a signature seems to be older than the key due to clock problems. This option makes these checks just a warn-
ing. See also --ignore-valid-from for timestamp issues on subkeys.
--ignore-valid-from |
GnuPG normally does not select and use subkeys created in the future. This option allows the use of such keys and
thus exhibits the pre-1.0.7 behaviour. You should not use this option unless there is some clock problem. See also
--ignore-time-conflict for timestamp issues with signatures.
--ignore-crc-error |
The ASCII armor used by OpenPGP is protected by a CRC checksum against transmission errors. Occasionally the CRC gets
mangled somewhere on the transmission channel but the actual content (which is protected by the OpenPGP protocol any-
way) is still okay. This option allows GnuPG to ignore CRC errors.
--ignore-mdc-error |
This option changes a MDC integrity protection failure into a warning. It is required to decrypt old messages which
did not use an MDC. It may also be useful if a message is partially garbled, but it is necessary to get as much data
as possible out of that garbled message. Be aware that a missing or failed MDC can be an indication of an attack.
Use with great caution; see also option --rfc2440.
--allow-weak-digest-algos |
Signatures made with known-weak digest algorithms are normally rejected with an ``invalid digest algorithm'' message.
This option allows the verification of signatures made with such weak algorithms. MD5 is the only digest algorithm
considered weak by default. See also --weak-digest to reject other digest algorithms.
--weak-digest name |
Treat the specified digest algorithm as weak. Signatures made over weak digests algorithms are normally rejected.
This option can be supplied multiple times if multiple algorithms should be considered weak. See also --allow-weak-
digest-algos to disable rejection of weak digests. MD5 is always considered weak, and does not need to be listed ex-
plicitly.
--no-default-keyring |
Do not add the default keyrings to the list of keyrings. Note that GnuPG will not operate without any keyrings, so if
you use this option and do not provide alternate keyrings via --keyring or --secret-keyring, then GnuPG will still
use the default public or secret keyrings.
--no-keyring |
Do not add use any keyrings even if specified as options.
--skip-verify |
Skip the signature verification step. This may be used to make the decryption faster if the signature verification is
not needed.
--with-key-data |
Print key listings delimited by colons (like --with-colons) and print the public key data.
--list-signatures |
--list-sigs |
Same as --list-keys, but the signatures are listed too. This command has the same effect as using --list-keys with
--with-sig-list. Note that in contrast to --check-signatures the key signatures are not verified. This command can
be used to create a list of signing keys missing in the lcoal keyring; for example:
gpg --list-sigs --with-colons USERID | \
awk -F: '$1=="sig" && $2=="?" {if($13){print $13}else{print $5}}'
--fast-list-mode |
Changes the output of the list commands to work faster; this is achieved by leaving some parts empty. Some applica-
tions don't need the user ID and the trust information given in the listings. By using this options they can get a
faster listing. The exact behaviour of this option may change in future versions. If you are missing some informa-
tion, don't use this option.
<--no-literal | This is not for normal use. Use the source to see for what it might be useful.
--set-filesize | This is not for normal use. Use the source to see for what it might be useful.
--show-session-key |
Display the session key used for one message. See --override-session-key for the counterpart of this option.
We think that Key Escrow is a Bad Thing; however the user should have the freedom to decide whether to go to prison
or to reveal the content of one specific message without compromising all messages ever encrypted for one secret key.
You can also use this option if you receive an encrypted message which is abusive or offensive, to prove to the ad-
ministrators of the messaging system that the ciphertext transmitted corresponds to an inappropriate plaintext so
they can take action against the offending user.
--override-session-key string |
--override-session-key-fd fd |
Don't use the public key but the session key string respective the session key taken from the first line read from
file descriptor fd. The format of this string is the same as the one printed by --show-session-key. This option is
normally not used but comes handy in case someone forces you to reveal the content of an encrypted message; using
this option you can do this without handing out the secret key. Note that using --override-session-key may reveal
the session key to all local users via the global process table. Often it is useful to combine this option with
--no-keyring.
--ask-sig-expire |
--no-ask-sig-expire |
When making a data signature, prompt for an expiration time. If this option is not specified, the expiration time set
via --default-sig-expire is used. --no-ask-sig-expire disables this option.
--default-sig-expire |
The default expiration time to use for signature expiration. Valid values are "0" for no expiration, a number fol-
lowed by the letter d (for days), w (for weeks), m (for months), or y (for years) (for example "2m" for two months,
or "5y" for five years), or an absolute date in the form YYYY-MM-DD. Defaults to "0".
--ask-cert-expire |
--no-ask-cert-expire |
When making a key signature, prompt for an expiration time. If this option is not specified, the expiration time set
via --default-cert-expire is used. --no-ask-cert-expire disables this option.
--default-cert-expire |
The default expiration time to use for key signature expiration. Valid values are "0" for no expiration, a number
followed by the letter d (for days), w (for weeks), m (for months), or y (for years) (for example "2m" for two
months, or "5y" for five years), or an absolute date in the form YYYY-MM-DD. Defaults to "0".
--default-new-key-algo string |
This option can be used to change the default algorithms for key generation. The string is similar to the arguments
required for the command --quick-add-key but slightly different. For example the current default of
"rsa2048/cert,sign+rsa2048/encr" (or "rsa3072") can be changed to the value of what we currently call future default,
which is "ed25519/cert,sign+cv25519/encr". You need to consult the source code to learn the details. Note that the
advanced key generation commands can always be used to specify a key algorithm directly.
--allow-secret-key-import | This is an obsolete option and is not used anywhere.
| | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | |